==> jtimer-1.3.3-sources.jar: org/chorem/jtimer/io/Saver.java <==
/*
 * #%L
 * jTimer
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2007 - 2012 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
/* *##%
 * Copyright (C) 2007,2009 Code Lutin
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *##%*/

package org.chorem.jtimer.io;

import java.util.Collection;

import org.chorem.jtimer.data.DataEventListener;
import org.chorem.jtimer.data.VetoableDataEventListener;
import org.chorem.jtimer.entities.TimerProject;

/**
 * Common interface for jtimer data savers.
 * 
 * @author chatellier
 * @version $Revision: 2518 $
 * 
 * Last update : $Date: 2009-05-22 13:17:51 +0200 (ven., 22 mai 2009) $
 * By : $Author: chatellier $
 */
public interface Saver extends DataEventListener, VetoableDataEventListener {

    /**
     * Set file directory.
     * 
     * @param directory directory
     */
    public void setSaveDirectory(String directory);

    /**
     * Set auto save delay (in milliseconds).
     * 
     * @param autoSaveDelay delay in milliseconds
     */
    public void setAutoSaveDelay(long autoSaveDelay);

    /**
     * Try to lock current saver directory.
     * 
     * @throws DataLockingException if can't obtain lock
     */
    public void lock() throws DataLockingException;

    /**
     * Try to unlock current saver directory.
     * 
     * @throws DataLockingException if there is no lock
     */
    public void unlock() throws DataLockingException;

    /**
     * Load a project list.
     * 
     * @return a collection of projects
     */
    public Collection<TimerProject> load();

}

==> jtimer-1.4.3-sources.jar: org/chorem/jtimer/io/Saver.java <==
/*
 * #%L
 * jTimer
 * 
 * $Id: Saver.java 2806 2012-03-07 16:38:55Z echatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2007 - 2012 CodeLutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package org.chorem.jtimer.io;

import java.util.Collection;

import org.chorem.jtimer.data.DataEventListener;
import org.chorem.jtimer.data.VetoableDataEventListener;
import org.chorem.jtimer.entities.TimerProject;

/**
 * Common interface for jtimer data savers.
 * 
 * @author chatellier
 * @version $Revision: 2806 $
 * 
 * Last update : $Date: 2012-03-07 17:38:55 +0100 (Wed, 07 Mar 2012) $
 * By : $Author: echatellier $
 */
public interface Saver extends DataEventListener, VetoableDataEventListener {

    /**
     * Set file directory.
     * 
     * @param directory directory
     */
    public void setSaveDirectory(String directory);

    /**
     * Set auto save delay (in milliseconds).
     * 
     * @param autoSaveDelay delay in milliseconds
     */
    public void setAutoSaveDelay(long autoSaveDelay);

    /**
     * Try to lock current saver directory.
     * 
     * @throws DataLockingException if can't obtain lock
     */
    public void lock() throws DataLockingException;

    /**
     * Try to unlock current saver directory.
     * 
     * @throws DataLockingException if there is no lock
     */
    public void unlock() throws DataLockingException;

    /**
     * Load a project list.
     * 
     * @return a collection of projects
     */
    public Collection<TimerProject> load();

}
